Crate record_player

Crate record_player 

Re-exports

pub use acoustic::AcousticConfig;
pub use acoustic::AcousticStatus;
pub use acoustic::CalibrationAnchor;
pub use acoustic::DeckRecoveryDiagnostic;
pub use acoustic::DeckRecoveryOperation;
pub use acoustic::ScratchAcousticDsp;
pub use acoustic::StylusCalibration;
pub use acoustic::WearScope;
pub use mechanics::ContactMode;
pub use mechanics::DeckMechanicalControl;
pub use mechanics::DeckMechanicalError;
pub use mechanics::DeckMechanicalSnapshot;
pub use mechanics::DeckMechanicalState;
pub use mechanics::DeckMechanicalTelemetry;
pub use mechanics::MotorMode;
pub use mechanics::NormalizedDeckControl;
pub use mechanics::PhysicalDeckConfig;
pub use mechanics::PhysicalDeckConfigError;
pub use scratch_gate::ScratchCrossfaderOwner;
pub use scratch_gate::ScratchGate;
pub use scratch_gate::ScratchGateSnapshot;
pub use scratch_gate::ScratchPerformance;
pub use scratch_gate::ScratchPerformanceError;
pub use scratch_gate::ScratchPerformanceInput;
pub use scratch_gate::ScratchPerformanceOutput;
pub use scratch_gate::ScratchPerformanceSnapshot;
pub use scratch_gate::ScratchPreset;
pub use scratch_gate::ScratchPresetDescriptor;
pub use scratch_gate::MAXIMUM_SCRATCH_RECORD_RATE;
pub use scratch_gate::MAX_SCRATCH_CLICKS;
pub use scratch_gate::MIN_SCRATCH_CLICKS;
pub use scratch_gate::SCRATCH_GATE_ALGORITHM_VERSION;
pub use scratch_gate::SCRATCH_GATE_SNAPSHOT_VERSION;
pub use scratch_gate::SCRATCH_PERFORMANCE_SNAPSHOT_VERSION;
pub use scratch_gate::SCRATCH_PRESET_CATALOG;
pub use gesture::*;

Modules

acoustic
gesture
mechanics
scratch_gate
spsc
A bounded mailbox for one producer and one consumer.
timed_control

Structs

ClipLoopState
DeckState
DeckViewState
MixerState
NeedleState
PlaybackState
PlayerConfig
PlayerEngine
PlayerState
PlayerViewState
ScratchState
TimedRegionState
TransportState
VinylVfxContext
VinylVfxProcessor
Preallocated state for one graph instance.

Enums

DeckId
HostCommand
LoadStatus
PlayerError
PlayerEvent
SurfaceRegion

Constants

DEFAULT_SHARP_CROSSFADER_WIDTH
VINYL_VFX_ADJACENT_GHOST
VINYL_VFX_CUT_CONSTELLATION
VINYL_VFX_INNER_FIRE
VINYL_VFX_MAX_SCENE
VINYL_VFX_NONE
VINYL_VFX_NULL_POINTS
Retired from the picker on 2026-09-09. The code stays reserved and the branch stays in process_frame: a take cut with this scene, and a share code carrying it, still render as they were made. See docs/DECK_VFX.md.
VINYL_VFX_OVERCUT
VINYL_VFX_PINCH
VINYL_VFX_SPLIT_WALLS
VINYL_VFX_THREE_NEEDLES
VINYL_VFX_WORN_HALO

Functions

sharp_crossfader_gains