Module gesture

Module gesture 

Structs

ScheduledScratchHandControl
Contains one hand control that is ready for the player timeline.
ScratchGestureConfig
Configures sample-clock scheduling and pointer calibration.
ScratchGestureMapper
Converts pointer motion to physical hand setpoints.
ScratchGestureSnapshot
Stores all gesture state that can affect later controls.
ScratchPointerSample
Describes one pointer sample in the host’s monotonic time domain.
ScratchPressureCalibration
Maps a normalized pointer-pressure value to a normal hand force.

Enums

ScratchGestureError