pub struct ScheduledScratchHandControl {
pub absolute_frame: u64,
pub pointer_id: u64,
pub hand_contact: bool,
pub hand_target_angle_rad: Option<f64>,
pub hand_target_angular_velocity_rad_s: f64,
pub hand_normal_force_n: f64,
pub hand_contact_radius_m: f64,
pub raw_pointer_angular_velocity_rad_s: f64,
pub velocity_was_limited: bool,
pub wrap_was_ambiguous: bool,
pub added_late_shift_frames: u64,
pub total_late_shift_frames: u64,
}Expand description
Contains one hand control that is ready for the player timeline.
Fields
absolute_frame: u64pointer_id: u64hand_contact: boolhand_target_angle_rad: Option<f64>hand_target_angular_velocity_rad_s: f64hand_normal_force_n: f64hand_contact_radius_m: f64raw_pointer_angular_velocity_rad_s: f64velocity_was_limited: boolwrap_was_ambiguous: booladded_late_shift_frames: u64total_late_shift_frames: u64Implementations
Sourceimpl ScheduledScratchHandControl
impl ScheduledScratchHandControl
Sourcepub fn merge(self, sequence: u64, control: PlayerControl) -> TimedPlayerControl
pub fn merge(self, sequence: u64, control: PlayerControl) -> TimedPlayerControl
Replaces only the hand fields in a complete player control.
Sourcepub fn merge_deck(self, control: DeckMechanicalControl) -> DeckMechanicalControl
pub fn merge_deck(self, control: DeckMechanicalControl) -> DeckMechanicalControl
Replaces only the hand fields in a deck control.