Module scratch_gate

Module scratch_gate 

Structs

ScratchGate
Audio-rate, travel-based scratch crossfader gate.
ScratchGateSnapshot
Stores all automatic gate state that can affect later audio frames.
ScratchPerformance
Canonical allocation-free scratch helper for physical player consumers.
ScratchPerformanceInput
Supplies one same-sample physical motion result to the scratch helper.
ScratchPerformanceOutput
Reports the exact gain and motion state for one audio frame.
ScratchPerformanceSnapshot
Stores all helper state that can affect later audible gain.
ScratchPresetDescriptor
Stable catalog data for native and Web hosts.
ScratchPresetParseError

Enums

ScratchCrossfaderOwner
Identifies which control owns the audible deck gain.
ScratchPerformanceError
ScratchPreset
Intent-aware automatic crossfader patterns for common scratch techniques.

Constants

MAXIMUM_SCRATCH_RECORD_RATE
MAX_SCRATCH_CLICKS
MIN_SCRATCH_CLICKS
SCRATCH_GATE_ALGORITHM_VERSION
SCRATCH_GATE_SNAPSHOT_VERSION
SCRATCH_PERFORMANCE_SNAPSHOT_VERSION
SCRATCH_PRESET_CATALOG