pub fn spsc_mailbox<T, Codec, const BYTES: usize>(
capacity: usize,
) -> Result<SpscEndpoints<T, Codec, BYTES>, SpscCreateError>Expand description
Creates one bounded mailbox and its two unique endpoints.
pub fn spsc_mailbox<T, Codec, const BYTES: usize>(
capacity: usize,
) -> Result<SpscEndpoints<T, Codec, BYTES>, SpscCreateError>Creates one bounded mailbox and its two unique endpoints.