pub struct PlayerControl {
pub deck: DeckMechanicalControl,
pub stylus_lowered: bool,
pub scratch_preset: ScratchPreset,
pub scratch_clicks: u8,
pub manual_crossfader_gain: f64,
}Expand description
One complete player control state at an exact render frame.
Fields
deck: DeckMechanicalControlstylus_lowered: boolscratch_preset: ScratchPresetscratch_clicks: u8manual_crossfader_gain: f64Implementations
Sourceimpl PlayerControl
impl PlayerControl
pub const fn new(deck: DeckMechanicalControl, stylus_lowered: bool) -> Self
Sourcepub const fn with_scratch(
self,
preset: ScratchPreset,
clicks: u8,
manual_crossfader_gain: f64,
) -> Self
pub const fn with_scratch( self, preset: ScratchPreset, clicks: u8, manual_crossfader_gain: f64, ) -> Self
Sets the complete scratch helper control for this sample-timed state.