pub struct ScratchGestureMapper { /* private fields */ }Expand description
Converts pointer motion to physical hand setpoints.
Implementations
Sourceimpl ScratchGestureMapper
impl ScratchGestureMapper
pub fn new(config: ScratchGestureConfig) -> Result<Self, ScratchGestureError>
pub const fn config(&self) -> ScratchGestureConfig
pub const fn active_pointer_id(&self) -> Option<u64>
pub const fn total_late_shift_frames(&self) -> u64
Sourcepub fn begin(
&mut self,
sample: ScratchPointerSample,
minimum_render_frame: u64,
record_angle_rad: f64,
) -> Result<ScheduledScratchHandControl, ScratchGestureError>
pub fn begin( &mut self, sample: ScratchPointerSample, minimum_render_frame: u64, record_angle_rad: f64, ) -> Result<ScheduledScratchHandControl, ScratchGestureError>
Starts a gesture without moving the record at contact time.
Sourcepub fn update(
&mut self,
sample: ScratchPointerSample,
minimum_render_frame: u64,
) -> Result<ScheduledScratchHandControl, ScratchGestureError>
pub fn update( &mut self, sample: ScratchPointerSample, minimum_render_frame: u64, ) -> Result<ScheduledScratchHandControl, ScratchGestureError>
Maps one move without low-pass filtering a reversal.
Sourcepub fn finish(
&mut self,
pointer_id: u64,
source_time_ns: u64,
minimum_render_frame: u64,
) -> Result<ScheduledScratchHandControl, ScratchGestureError>
pub fn finish( &mut self, pointer_id: u64, source_time_ns: u64, minimum_render_frame: u64, ) -> Result<ScheduledScratchHandControl, ScratchGestureError>
Schedules release and makes the mapper available for another pointer.
pub fn snapshot(&self) -> ScratchGestureSnapshot
pub fn restore( &mut self, snapshot: &ScratchGestureSnapshot, ) -> Result<(), ScratchGestureError>